@@ -90,10 +90,7 @@
 #include <QImageIOPlugin>
 #include <QLocale>
 #include <QThread>
-
-#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
 #include <QTimeZone>
-#endif
 
 // Allow the code to works on all QT versions supported by KDE
 // project (Qt 5.15 and Qt 6.x) to easy backports fixes.
@@ -319,11 +316,7 @@ static void readMetadata(const Imf::Header &header, QImage &image)
         }
         auto dateTime = QDateTime::fromString(QString::fromStdString(capDate->value()), QStringLiteral("yyyy:MM:dd HH:mm:ss"));
         if (dateTime.isValid()) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
             dateTime.setTimeZone(QTimeZone::fromSecondsAheadOfUtc(off));
-#else
-            dateTime.setOffsetFromUtc(off);
-#endif
             image.setText(QStringLiteral("CreationDate"), dateTime.toString(Qt::ISODate));
         }
     }
